@@ -5,6 +5,7 @@ import emcee as mc
 import numpy as np
 import scipy.stats as st
 from scipy.linalg import cho_solve, cholesky, solve_triangular
+import sklearn
 from sklearn.utils import check_random_state
 from skopt.learning import GaussianProcessRegressor
 from skopt.learning.gaussian_process.gpr import _param_for_white_kernel_in_Sum
@@ -85,7 +86,7 @@ class BayesGPR(GaussianProcessRegressor):
         from the space of allowed theta-values. If greater than 0, all bounds
         must be finite. Note that n_restarts_optimizer == 0 implies that one
         run is performed.
-    normalize_y : boolean, optional (default: True)
+    normalize_y : boolean, optional (default: False)
         Whether the target values y are normalized, i.e., the mean of the
         observed target values become zero. This parameter should be set to
         True if the target values' mean is expected to differ considerable from
@@ -151,7 +152,7 @@ class BayesGPR(GaussianProcessRegressor):
         alpha=1e-10,
         optimizer="fmin_l_bfgs_b",
         n_restarts_optimizer=0,
-        normalize_y=True,
+        normalize_y=False,
         warp_inputs=False,
         copy_X_train=True,
         random_state=None,
@@ -458,10 +459,23 @@ class BayesGPR(GaussianProcessRegressor):
         # Update data, if available:
         if X is not None:
             if self.normalize_y:
-                self.y_train_mean_ = np.mean(y, axis=0)
-                y = y - self.y_train_mean_
+                self._y_train_mean = np.mean(y, axis=0)
+                if int(sklearn.__version__[2:4]) >= 23:
+                    self._y_train_std = np.std(y, axis=0)
             else:
-                self.y_train_mean_ = np.zeros(1)
+                self._y_train_mean = np.zeros(1)
+                if int(sklearn.__version__[2:4]) >= 23:
+                    self._y_train_std = 1
+            if int(sklearn.__version__[2:4]) >= 23:
+                self.y_train_std_ = self._y_train_std
+                self.y_train_mean_ = self._y_train_mean
+            else:
+                self.y_train_mean_ = self._y_train_mean
+                self.y_train_std_ = 1
+            y = (y - self.y_train_mean_) / self.y_train_std_
+
+            if noise_vector is not None:
+                noise_vector = np.array(noise_vector) / np.power(self.y_train_std_, 2)
 
             self.X_train_ = np.copy(X) if self.copy_X_train else X
             self.y_train_ = np.copy(y) if self.copy_X_train else y
@@ -576,6 +590,15 @@ class BayesGPR(GaussianProcessRegressor):
 
         """
         self.kernel = self._kernel
+        # In sklearn >= 23 the normalization includes scaling the output by the
+        # standard deviation. We need to scale the noise_vector accordingly here:
+        if (
+            int(sklearn.__version__[2:4]) >= 23
+            and self.normalize_y
+            and noise_vector is not None
+        ):
+            y_std = np.std(y, axis=0)
+            noise_vector = np.array(noise_vector) / np.power(y_std, 2)
         self._apply_noise_vector(len(y), noise_vector)
         super().fit(X, y)
 
@@ -652,6 +675,7 @@ class BayesGPR(GaussianProcessRegressor):
             current_warp_alphas = np.copy(self.warp_alphas_)
             current_warp_betas = np.copy(self.warp_betas_)
         current_theta = self.theta
+        n_dims = len(current_theta)
         current_K_inv = np.copy(self.K_inv_)
         current_L = np.copy(self.L_)
         current_alpha = np.copy(self.alpha_)
@@ -659,8 +683,8 @@ class BayesGPR(GaussianProcessRegressor):
         for i, j in enumerate(ind):
             if self.warp_inputs:
                 validate_zeroone(X)
-                theta = self.chain_[j][: len(self.kernel_.theta)]
-                warp_params = self.chain_[j][len(self.kernel_.theta) :]
+                theta = self.chain_[j][:n_dims]
+                warp_params = self.chain_[j][n_dims:]
                 alphas, betas = warp_params[: X.shape[1]], warp_params[X.shape[1] :]
                 self.create_warpers(alphas, betas)
                 self.rewarp()
